==> kfritz_0.0.7.orig.tar.gz: kfritz/ContainerWidget.h <==
/*
 * KFritz
 *
 * Copyright (C) 2011 Joachim Wilke <kfritz@joachim-wilke.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */
 
#ifndef CONTAINERWIDGET_H_
#define CONTAINERWIDGET_H_

#include <QWidget>
#include "QAdaptTreeView.h"
#include "KFonbookModel.h"
#include "KCalllistProxyModel.h"

class ContainerWidget: public QWidget {
private:
	QAdaptTreeView *treeview;
	KFonbookModel *fonbookModel;
	KCalllistProxyModel *calllistModel;
public:
	ContainerWidget(QWidget *parent, QAdaptTreeView *treeview, KFonbookModel *model);
	ContainerWidget(QWidget *parent, QAdaptTreeView *treeview, KCalllistProxyModel *model);
	virtual ~ContainerWidget();
	QAdaptTreeView *getTreeView() { return treeview; }
	KFonbookModel *getFonbookModel() { return fonbookModel; }
	KCalllistProxyModel *getCalllistModel() { return calllistModel; }
	bool isFonbook() { return fonbookModel ? true : false; }
	bool isCalllist() { return calllistModel ? true : false; }
};

#endif /* CONTAINERWIDGET_H_ */

==> kfritz_0.0.12a.orig.tar.gz: kfritz/ContainerWidget.h <==
/*
 * KFritz
 *
 * Copyright (C) 2011 Joachim Wilke <kfritz@joachim-wilke.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */
 
#ifndef CONTAINERWIDGET_H
#define CONTAINERWIDGET_H

#include <QWidget>

#include "QAdaptTreeView.h"
#include "KFonbookModel.h"
#include "KCalllistProxyModel.h"

class ContainerWidget: public QWidget {
private:
	QAdaptTreeView *treeview;
	KFonbookModel *fonbookModel;
	KCalllistProxyModel *calllistModel;
public:
	ContainerWidget(QWidget *parent, QAdaptTreeView *treeview, KFonbookModel *model);
	ContainerWidget(QWidget *parent, QAdaptTreeView *treeview, KCalllistProxyModel *model);
	virtual ~ContainerWidget();
	QAdaptTreeView *getTreeView() { return treeview; }
	KFonbookModel *getFonbookModel() { return fonbookModel; }
	KCalllistProxyModel *getCalllistModel() { return calllistModel; }
	bool isFonbook() { return fonbookModel ? true : false; }
	bool isCalllist() { return calllistModel ? true : false; }
};

#endif /* CONTAINERWIDGET_H_ */
